- Set METAVAR in typer-repyt for nested models correctly
- Show start and end of command if logging is attached?
- consider an `unpack_path` parameter for `_x` methods that serialize the response by extracting a JMESPath from the
  response
